@@ -22,7 +22,7 @@ Readonly::Scalar my $BLOCK_SIZE => 4_096;
 Readonly::Array my @PAR_SEP => (q{&}, q{;});
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -832,9 +832,17 @@ L<URI::Escape>.
 
 =head1 SEE ALSO
 
-L<CGI::Pure::Fast>,
-L<CGI::Pure::ModPerl2>,
-L<CGI::Pure::Save>.
+=over
+
+=item L<CGI::Pure::Fast>
+
+Fast Common Gateway Interface Class for CGI::Pure.
+
+=item L<CGI::Pure::Save>
+
+Common Gateway Interface Class for loading/saving object in file.
+
+=back
 
 =head1 AUTHOR
 
@@ -844,10 +852,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2004-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
